<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>NotificationActionsComboWidget</name>
    <message>
        <location filename="../notificationwidgets.cpp" line="131"/>
        <source>Actions:</source>
        <translation>動作:</translation>
    </message>
    <message>
        <location filename="../notificationwidgets.cpp" line="155"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Notifyd</name>
    <message>
        <location filename="../notifyd.cpp" line="274"/>
        <source>Clear All</source>
        <translation>すべて消去</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="285"/>
        <source>Do Not Disturb</source>
        <translation>サイレント</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="293"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message numerus="yes">
        <location filename="../notifyd.cpp" line="300"/>
        <location filename="../notifyd.cpp" line="358"/>
        <location filename="../notifyd.cpp" line="379"/>
        <source>%n Unattended Notification(s)</source>
        <translation>
            <numerusform>未確認の通知が %n 件あります</numerusform>
        </translation>
    </message>
</context>
</TS>
